from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ScaleCls:
	"""Scale commands group definition. 10 total commands, 8 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("scale", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	@property
	def maximum(self):
		"""maximum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_maximum'):
			from .Maximum import MaximumCls
			self._maximum = MaximumCls(self._core, self._cmd_group)
		return self._maximum

	@property
	def minimum(self):
		"""minimum commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_minimum'):
			from .Minimum import MinimumCls
			self._minimum = MinimumCls(self._core, self._cmd_group)
		return self._minimum

	@property
	def pdivision(self):
		"""pdivision commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pdivision'):
			from .Pdivision import PdivisionCls
			self._pdivision = PdivisionCls(self._core, self._cmd_group)
		return self._pdivision

	@property
	def refPosition(self):
		"""refPosition commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_refPosition'):
			from .RefPosition import RefPositionCls
			self._refPosition = RefPositionCls(self._core, self._cmd_group)
		return self._refPosition

	@property
	def rvalue(self):
		"""rvalue commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rvalue'):
			from .Rvalue import RvalueCls
			self._rvalue = RvalueCls(self._core, self._cmd_group)
		return self._rvalue

	@property
	def refLevel(self):
		"""refLevel commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_refLevel'):
			from .RefLevel import RefLevelCls
			self._refLevel = RefLevelCls(self._core, self._cmd_group)
		return self._refLevel

	def set(self, scale: float, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:Y[:SCALe] \n
		Snippet: driver.display.window.trace.y.scale.set(scale = 1.0, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command defines the value range displayed on the y-axis.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn off automatic scaling of the y-axis (method RsFswp.Display.Window.Trace.Y.Scale.Auto.set) . \n
			:param scale: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.decimal_value_to_str(scale)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe {param}')

	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> float:
		"""SCPI: DISPlay[:WINDow<n>]:TRACe<t>:Y[:SCALe] \n
		Snippet: value: float = driver.display.window.trace.y.scale.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This command defines the value range displayed on the y-axis.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn off automatic scaling of the y-axis (method RsFswp.Display.Window.Trace.Y.Scale.Auto.set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: scale: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TRACe{trace_cmd_val}:Y:SCALe?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'ScaleCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ScaleCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IpnCls:
	"""Ipn commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ipn", core, parent)

	def get(self, trace=repcap.Trace.Default) -> float:
		"""SCPI: FETCh:PNOise<t>:IPN \n
		Snippet: value: float = driver.applications.k40PhaseNoise.fetch.pnoise.ipn.get(trace = repcap.Trace.Default) \n
		No command help available \n
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Pnoise')
			:return: value: No help available"""
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'FETCh:PNOise{trace_cmd_val}:IPN?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RightCls:
	"""Right commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("right", core, parent)

	def set(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default, opc_timeout_ms: int = -1) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>:MAXimum:RIGHt \n
		Snippet: driver.applications.k60Transient.calculate.deltaMarker.maximum.right.set(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		This command moves a delta marker to the next positive peak value on the trace. The search includes only measurement
		values to the right of the current marker position. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:MAXimum:RIGHt', opc_timeout_ms)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, record_length: float) -> None:
		"""SCPI: [SENSe]:DDEMod:RLENgth[:VALue] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.rlength.value.set(record_length = 1.0) \n
		This command defines or queries the capture length for further processing, e.g. for burst search. Note that the maximum
		capture length depends on the sample rate for signal capture (see [SENSe:]DDEMod:PRATe) . \n
			:param record_length: The capture length can be defined in time (seconds) or symbols (SYM) . The return value is always in time (s) . To query the capture length in symbols, use the [SENSe:]DDEMod:RLENgth:SYMBols[:VALue] command. Unit: S
		"""
		param = Conversions.decimal_value_to_str(record_length)
		self._core.io.write(f'SENSe:DDEMod:RLENgth:VALue {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:RLENgth[:VALue] \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.rlength.value.get() \n
		This command defines or queries the capture length for further processing, e.g. for burst search. Note that the maximum
		capture length depends on the sample rate for signal capture (see [SENSe:]DDEMod:PRATe) . \n
			:return: record_length: The capture length can be defined in time (seconds) or symbols (SYM) . The return value is always in time (s) . To query the capture length in symbols, use the [SENSe:]DDEMod:RLENgth:SYMBols[:VALue] command. Unit: S"""
		response = self._core.io.query_str(f'SENSe:DDEMod:RLENgth:VALue?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AoffCls:
	"""Aoff commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("aoff", core, parent)

	def set(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> None:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:BPOWer:AOFF \n
		Snippet: driver.calculate.marker.function.bpower.aoff.set(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
		"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		self._core.io.write(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:BPOWer:AOFF')

	def set_with_opc(self, window=repcap.Window.Default, marker=repcap.Marker.Default, opc_timeout_ms: int = -1) -> None:
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:BPOWer:AOFF \n
		Snippet: driver.calculate.marker.function.bpower.aoff.set_with_opc(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:BPOWer:AOFF', opc_timeout_ms)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CcountCls:
	"""Ccount commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("ccount", core, parent)

	def get(self, relay: enums.Relay) -> int:
		"""SCPI: DIAGnostic:INFO:CCOunt \n
		Snippet: value: int = driver.diagnostic.info.ccount.get(relay = enums.Relay.AC_enable) \n
		This command queries how many switching cycles the individual relays have performed since they were installed. \n
			:param relay: ATT5 Mechanical Attenuation 05 DB ATT10 Mechanical Attenuation 10 DB ATT20 Mechanical Attenuation 20 DB ATT40 Mechanical Attenuation 40 DB CAL Mechanical Calibration Source ACDC Mechanical Attenuation Coupling PREamp Preamplifier Bypass PRES Preselector 1: PRESEL RFAB Preselector 1: RFAB PRE Preselector 1: PREAMP30MHZ ATT Preselector 1: ATTINPUT2 INP Preselector 1: INPUT2 EXT_ Preselector 2: EXT_RELAIS SATT10 | SATT20 | SATT40 Mechanical attenuation (10, 20 and 40 dB) for the optional Signal Source hardware. SCAL DUT bypass (available with the optional Signal Source hardware) .
			:return: cycles: Number of switching cycles."""
		param = Conversions.enum_scalar_to_str(relay, enums.Relay)
		response = self._core.io.query_str(f'DIAGnostic:INFO:CCOunt? {param}')
		return Conversions.str_to_int(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class XCls:
	"""X commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("x", core, parent)

	@property
	def mode(self):
		"""mode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mode'):
			from .Mode import ModeCls
			self._mode = ModeCls(self._core, self._cmd_group)
		return self._mode

	def set(self, time: float) -> None:
		"""SCPI: [SENSe]:ADEMod:PM:RPOint[:X] \n
		Snippet: driver.sense.ademod.pm.rpoint.x.set(time = 1.0) \n
		This command determines the position where the phase of the PM-demodulated signal is set to 0 rad. The maximum value
		depends on the measurement time selected in the instrument; this value is output in response to the query ADEM:PM:RPO:X?
		MAX. \n
			:param time: 0 s to measurement time Unit: S
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'SENSe:ADEMod:PM:RPOint:X {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:ADEMod:PM:RPOint[:X] \n
		Snippet: value: float = driver.sense.ademod.pm.rpoint.x.get() \n
		This command determines the position where the phase of the PM-demodulated signal is set to 0 rad. The maximum value
		depends on the measurement time selected in the instrument; this value is output in response to the query ADEM:PM:RPO:X?
		MAX. \n
			:return: time: 0 s to measurement time Unit: S"""
		response = self._core.io.query_str(f'SENSe:ADEMod:PM:RPOint:X?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'XCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = XCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class VideoCls:
	"""Video commands group definition. 4 total commands, 3 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("video", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	@property
	def ratio(self):
		"""ratio commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ratio'):
			from .Ratio import RatioCls
			self._ratio = RatioCls(self._core, self._cmd_group)
		return self._ratio

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def set(self, bandwidth: float) -> None:
		"""SCPI: [SENSe]:BWIDth:VIDeo \n
		Snippet: driver.sense.bandwidth.video.set(bandwidth = 1.0) \n
		This command defines the video bandwidth.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn off automatic VBW selection ([SENSe:]BWIDth:VIDeo:AUTO) . \n
			:param bandwidth: Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(bandwidth)
		self._core.io.write(f'SENSe:BWIDth:VIDeo {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:BWIDth:VIDeo \n
		Snippet: value: float = driver.sense.bandwidth.video.get() \n
		This command defines the video bandwidth.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Turn off automatic VBW selection ([SENSe:]BWIDth:VIDeo:AUTO) . \n
			:return: bandwidth: Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:BWIDth:VIDeo?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'VideoCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = VideoCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class LevelCls:
	"""Level commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("level", core, parent)

	def set(self, level: enums.LowHigh, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:LOSCillator:SOURce:EXTernal:LEVel \n
		Snippet: driver.inputPy.loscillator.source.external.level.set(level = enums.LowHigh.HIGH, inputIx = repcap.InputIx.Default) \n
		This command selects the level of an external LO signal that is fed into the R&S FSWP.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select additive noise or pulsed additive noise measurement (CONFigure:PNOise:MEASurement) .
			- Select an external local oscillator (method RsFswp.InputPy.Loscillator.Source.set) . \n
			:param level: HIGH LO signal with high level characteristics. LOW LO signal with low level characteristics.
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.enum_scalar_to_str(level, enums.LowHigh)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:LOSCillator:SOURce:EXTernal:LEVel {param}')

	# noinspection PyTypeChecker
	def get(self, inputIx=repcap.InputIx.Default) -> enums.LowHigh:
		"""SCPI: INPut<ip>:LOSCillator:SOURce:EXTernal:LEVel \n
		Snippet: value: enums.LowHigh = driver.inputPy.loscillator.source.external.level.get(inputIx = repcap.InputIx.Default) \n
		This command selects the level of an external LO signal that is fed into the R&S FSWP.
			INTRO_CMD_HELP: Prerequisites for this command \n
			- Select additive noise or pulsed additive noise measurement (CONFigure:PNOise:MEASurement) .
			- Select an external local oscillator (method RsFswp.InputPy.Loscillator.Source.set) . \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: level: HIGH LO signal with high level characteristics. LOW LO signal with low level characteristics."""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:LOSCillator:SOURce:EXTernal:LEVel?')
		return Conversions.str_to_scalar_enum(response, enums.LowHigh)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, evm_calc: enums.EvmCalc) -> None:
		"""SCPI: [SENSe]:DDEMod:ECALc[:MODE] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.ecalc.mode.set(evm_calc = enums.EvmCalc.MACPower) \n
		This command defines the calculation formula for EVM. \n
			:param evm_calc: SIGNal | SYMBol | MECPower | MACPower SIGNal Calculation normalized to the mean power of the reference signal at the symbol instants. SYMBol Calculation normalized to the maximum power of the reference signal at the symbol instants. MECPower Calculation normalized to the mean expected power of the measurement signal at the symbol instants MACPower Calculation normalized to the maximum expected power of the measurement signal at the symbol instants
		"""
		param = Conversions.enum_scalar_to_str(evm_calc, enums.EvmCalc)
		self._core.io.write(f'SENSe:DDEMod:ECALc:MODE {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.EvmCalc:
		"""SCPI: [SENSe]:DDEMod:ECALc[:MODE] \n
		Snippet: value: enums.EvmCalc = driver.applications.k70Vsa.sense.ddemod.ecalc.mode.get() \n
		This command defines the calculation formula for EVM. \n
			:return: evm_calc: SIGNal | SYMBol | MECPower | MACPower SIGNal Calculation normalized to the mean power of the reference signal at the symbol instants. SYMBol Calculation normalized to the maximum power of the reference signal at the symbol instants. MECPower Calculation normalized to the mean expected power of the measurement signal at the symbol instants MACPower Calculation normalized to the maximum expected power of the measurement signal at the symbol instants"""
		response = self._core.io.query_str(f'SENSe:DDEMod:ECALc:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EvmCalc)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class NameCls:
	"""Name commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("name", core, parent)

	def set(self, filename: str) -> None:
		"""SCPI: MMEMory:NAME \n
		Snippet: driver.massMemory.name.set(filename = '1') \n
		This command has several purposes, depending on the context it is used in.
			- It creates a new and empty file.
			- It defines the file name for screenshots taken with method RsFswp.HardCopy.Immediate.set. Note that you have to route the printer output to a file. \n
			:param filename: String containing the path and name of the target file.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'MMEMory:NAME {param}')

	def get(self) -> str:
		"""SCPI: MMEMory:NAME \n
		Snippet: value: str = driver.massMemory.name.get() \n
		This command has several purposes, depending on the context it is used in.
			- It creates a new and empty file.
			- It defines the file name for screenshots taken with method RsFswp.HardCopy.Immediate.set. Note that you have to route the printer output to a file. \n
			:return: filename: String containing the path and name of the target file."""
		response = self._core.io.query_str(f'MMEMory:NAME?')
		return trim_str_response(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FskCls:
	"""Fsk commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("fsk", core, parent)

	@property
	def cfdrift(self):
		"""cfdrift commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cfdrift'):
			from .Cfdrift import CfdriftCls
			self._cfdrift = CfdriftCls(self._core, self._cmd_group)
		return self._cfdrift

	@property
	def derror(self):
		"""derror commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_derror'):
			from .Derror import DerrorCls
			self._derror = DerrorCls(self._core, self._cmd_group)
		return self._derror

	@property
	def mdeviation(self):
		"""mdeviation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mdeviation'):
			from .Mdeviation import MdeviationCls
			self._mdeviation = MdeviationCls(self._core, self._cmd_group)
		return self._mdeviation

	@property
	def rdeviation(self):
		"""rdeviation commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rdeviation'):
			from .Rdeviation import RdeviationCls
			self._rdeviation = RdeviationCls(self._core, self._cmd_group)
		return self._rdeviation

	def clone(self) -> 'FskCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FskCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	def get(self, trace_mode: enums.TraceModeB) -> float:
		"""SCPI: [SENSe]:ADEMod:FM[:TDOMain]:RESult \n
		Snippet: value: float = driver.sense.ademod.fm.tdomain.result.get(trace_mode = enums.TraceModeB.AVERage) \n
		This command reads the result data of the evaluated signal in the specified trace mode. The data format of the output
		data block is defined by the FORMat command (see method RsFswp.FormatPy.Data.set) . The trace results are configured for
		a specific evaluation. The following table indicates which command syntax refers to which evaluation method, as well as
		the output unit of the results.
			Table Header: Command syntax / Evaluation method / Output unit \n
			- ACV[:TDOMain] / AC-Video time domain / V
			- ACV:AFSpectrum / AC-Video spectrum / V
			- AM[:ABSolute][:TDOMain] / RF time domain / dBm
			- AM:RELative[:TDOMain] / AM time domain / %
			- AM:RELative:AFSPectrum / AM spectrum / %
			- FM[:TDOMain] / FM time domain / kHz
			- FM:AFSPectrum / FM spectrum / kHz
			- PM[:TDOMain] / PM time domain / rad or °
			- PM:AFSPectrum / PM spectrum / rad or °
			- SPECtrum / RF spectrum / dBm (logarithmic display) or V (linear display) . \n
			:param trace_mode: WRITe | AVERage | MAXHold | MINHold
			:return: trace_mode_result: The specified trace mode must be one of those configured by SENS:ADEM:Evaluation:TYPE, see [SENSe:]ADEMod:SPECtrum[:TYPE]. Otherwise a query error is generated."""
		param = Conversions.enum_scalar_to_str(trace_mode, enums.TraceModeB)
		response = self._core.io.query_str(f'SENSe:ADEMod:FM:TDOMain:RESult? {param}')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RemoveCls:
	"""Remove commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("remove", core, parent)

	def set(self, touchStone=repcap.TouchStone.Default) -> None:
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:SLISt<sli>:REMove \n
		Snippet: driver.sense.correction.fresponse.user.slist.remove.set(touchStone = repcap.TouchStone.Default) \n
		No command help available \n
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
		"""
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		self._core.io.write(f'SENSe:CORRection:FRESponse:USER:SLISt{touchStone_cmd_val}:REMove')

	def set_with_opc(self, touchStone=repcap.TouchStone.Default, opc_timeout_ms: int = -1) -> None:
		touchStone_cmd_val = self._cmd_group.get_repcap_cmd_value(touchStone, repcap.TouchStone)
		"""SCPI: [SENSe]:CORRection:FRESponse:USER:SLISt<sli>:REMove \n
		Snippet: driver.sense.correction.fresponse.user.slist.remove.set_with_opc(touchStone = repcap.TouchStone.Default) \n
		No command help available \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param touchStone: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Slist')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:CORRection:FRESponse:USER:SLISt{touchStone_cmd_val}:REMove', opc_timeout_ms)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ConditionCls:
	"""Condition commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("condition", core, parent)

	def get(self) -> str:
		"""SCPI: STATus:QUEStionable:TRANsducer:CONDition \n
		Snippet: value: str = driver.status.questionable.transducer.condition.get() \n
		No command help available \n
			:return: channel_name: No help available"""
		response = self._core.io.query_str(f'STATus:QUEStionable:TRANsducer:CONDition?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DefineCls:
	"""Define commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("define", core, parent)

	def set(self, placeholder: str, type_py: str, interface: str, serial_no: str, powerMeter=repcap.PowerMeter.Default) -> None:
		"""SCPI: SYSTem:COMMunicate:RDEVice:PMETer<p>:DEFine \n
		Snippet: driver.system.communicate.rdevice.pmeter.define.set(placeholder = '1', type_py = '1', interface = '1', serial_no = '1', powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param placeholder: No help available
			:param type_py: No help available
			:param interface: No help available
			:param serial_no: No help available
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('placeholder', placeholder, DataType.String), ArgSingle('type_py', type_py, DataType.String), ArgSingle('interface', interface, DataType.String), ArgSingle('serial_no', serial_no, DataType.String))
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		self._core.io.write(f'SYSTem:COMMunicate:RDEVice:PMETer{powerMeter_cmd_val}:DEFine {param}'.rstrip())

	# noinspection PyTypeChecker
	class DefineStruct(StructBase):
		"""Response structure. Fields: \n
			- Placeholder: str: No parameter help available
			- Type_Py: str: No parameter help available
			- Interface: str: No parameter help available
			- Serial_No: str: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_str('Placeholder'),
			ArgStruct.scalar_str('Type_Py'),
			ArgStruct.scalar_str('Interface'),
			ArgStruct.scalar_str('Serial_No')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Placeholder: str = None
			self.Type_Py: str = None
			self.Interface: str = None
			self.Serial_No: str = None

	def get(self, powerMeter=repcap.PowerMeter.Default) -> DefineStruct:
		"""SCPI: SYSTem:COMMunicate:RDEVice:PMETer<p>:DEFine \n
		Snippet: value: DefineStruct = driver.system.communicate.rdevice.pmeter.define.get(powerMeter = repcap.PowerMeter.Default) \n
		No command help available \n
			:param powerMeter: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Pmeter')
			:return: structure: for return value, see the help for DefineStruct structure arguments."""
		powerMeter_cmd_val = self._cmd_group.get_repcap_cmd_value(powerMeter, repcap.PowerMeter)
		return self._core.io.query_struct(f'SYSTem:COMMunicate:RDEVice:PMETer{powerMeter_cmd_val}:DEFine?', self.__class__.DefineStruct())



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TraceCls:
	"""Trace commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trace", core, parent)

	def set(self, trace_limit: List[float], window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: CALCulate<n>:LIMit<li>:TRACe \n
		Snippet: driver.applications.k30NoiseFigure.calculate.limit.trace.set(trace_limit = [1.1, 2.2, 3.3], window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command links a limit line to one or more traces. Note that this command is maintained for compatibility reasons
		only. Limit lines no longer need to be assigned to a trace explicitly. The trace to be checked can be defined directly
		(as a suffix) in the new command to activate the limit check (see method RsFswp.Calculate.Limit.Trace.Check.set) . \n
			:param trace_limit: 1 to 4
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.list_to_csv_str(trace_limit)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:TRACe {param}')

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default) -> List[float]:
		"""SCPI: CALCulate<n>:LIMit<li>:TRACe \n
		Snippet: value: List[float] = driver.applications.k30NoiseFigure.calculate.limit.trace.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default) \n
		This command links a limit line to one or more traces. Note that this command is maintained for compatibility reasons
		only. Limit lines no longer need to be assigned to a trace explicitly. The trace to be checked can be defined directly
		(as a suffix) in the new command to activate the limit check (see method RsFswp.Calculate.Limit.Trace.Check.set) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: trace_limit: 1 to 4"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_bin_or_ascii_float_list(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:TRACe?')
		return response



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal.Types import DataType
from .......Internal.ArgSingleList import ArgSingleList
from .......Internal.ArgSingle import ArgSingle
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, position: float, filename: str, store=repcap.Store.Default) -> None:
		"""SCPI: MMEMory:STORe<n>:IQ:STATe \n
		Snippet: driver.applications.k70Vsa.massMemory.store.iq.state.set(position = 1.0, filename = '1', store = repcap.Store.Default) \n
		This command writes the captured I/Q data to a file. The file extension is *.iq.tar. By default, the contents of the file
		are in 32-bit floating point format. \n
			:param position: 1..n
			:param filename: String containing the path and name of the target file.
			:param store: optional repeated capability selector. Default value: Pos1 (settable in the interface 'Store')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('position', position, DataType.Float), ArgSingle('filename', filename, DataType.String))
		store_cmd_val = self._cmd_group.get_repcap_cmd_value(store, repcap.Store)
		self._core.io.write(f'MMEMory:STORe{store_cmd_val}:IQ:STATe {param}'.rstrip())



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DisplayCls:
	"""Display commands group definition. 67 total commands, 17 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("display", core, parent)

	@property
	def window(self):
		"""window commands group. 9 Sub-classes, 0 commands."""
		if not hasattr(self, '_window'):
			from .Window import WindowCls
			self._window = WindowCls(self._core, self._cmd_group)
		return self._window

	@property
	def minfo(self):
		"""minfo commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_minfo'):
			from .Minfo import MinfoCls
			self._minfo = MinfoCls(self._core, self._cmd_group)
		return self._minfo

	@property
	def wselect(self):
		"""wselect commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_wselect'):
			from .Wselect import WselectCls
			self._wselect = WselectCls(self._core, self._cmd_group)
		return self._wselect

	@property
	def annotation(self):
		"""annotation commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_annotation'):
			from .Annotation import AnnotationCls
			self._annotation = AnnotationCls(self._core, self._cmd_group)
		return self._annotation

	@property
	def atab(self):
		"""atab commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_atab'):
			from .Atab import AtabCls
			self._atab = AtabCls(self._core, self._cmd_group)
		return self._atab

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	@property
	def logo(self):
		"""logo commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_logo'):
			from .Logo import LogoCls
			self._logo = LogoCls(self._core, self._cmd_group)
		return self._logo

	@property
	def theme(self):
		"""theme commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_theme'):
			from .Theme import ThemeCls
			self._theme = ThemeCls(self._core, self._cmd_group)
		return self._theme

	@property
	def cmap(self):
		"""cmap commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_cmap'):
			from .Cmap import CmapCls
			self._cmap = CmapCls(self._core, self._cmd_group)
		return self._cmap

	@property
	def faccess(self):
		"""faccess commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_faccess'):
			from .Faccess import FaccessCls
			self._faccess = FaccessCls(self._core, self._cmd_group)
		return self._faccess

	@property
	def preSelector(self):
		"""preSelector commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_preSelector'):
			from .PreSelector import PreSelectorCls
			self._preSelector = PreSelectorCls(self._core, self._cmd_group)
		return self._preSelector

	@property
	def touchscreen(self):
		"""touchscreen commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_touchscreen'):
			from .Touchscreen import TouchscreenCls
			self._touchscreen = TouchscreenCls(self._core, self._cmd_group)
		return self._touchscreen

	@property
	def tbar(self):
		"""tbar commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tbar'):
			from .Tbar import TbarCls
			self._tbar = TbarCls(self._core, self._cmd_group)
		return self._tbar

	@property
	def sbar(self):
		"""sbar commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sbar'):
			from .Sbar import SbarCls
			self._sbar = SbarCls(self._core, self._cmd_group)
		return self._sbar

	@property
	def skeys(self):
		"""skeys commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_skeys'):
			from .Skeys import SkeysCls
			self._skeys = SkeysCls(self._core, self._cmd_group)
		return self._skeys

	@property
	def iterm(self):
		"""iterm commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_iterm'):
			from .Iterm import ItermCls
			self._iterm = ItermCls(self._core, self._cmd_group)
		return self._iterm

	@property
	def blighting(self):
		"""blighting commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_blighting'):
			from .Blighting import BlightingCls
			self._blighting = BlightingCls(self._core, self._cmd_group)
		return self._blighting

	def clone(self) -> 'DisplayCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DisplayCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DataCls:
	"""Data commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("data", core, parent)

	def set(self, data: str) -> None:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:DATA \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.search.sync.data.set(data = '1') \n
		This command defines the sync sequence of a sync pattern. The pattern must have been selected before using
		[SENSe:]DDEMod:SEARch:SYNC:NAME. Important: The value range of a symbol depends on the degree of modulation,e.g. for an
		8PSK modulation the value range is from 0 to 7. The degree of modulation belongs to the pattern and is set using the
		DDEM:SEAR:SYNC:NST command (see [SENSe:]DDEMod:SEARch:SYNC:NSTate) . \n
			:param data: Four values represent a symbol (hexadecimal format) . The value range of a symbol depends on the degree of modulation. With a degree of modulation of 4, all symbols have a value range of: 0000, 0001, 0002, 0003 With a degree of modulation of 8: 0000, 0001, 0002, 0003, 0004, 0005, 0006, 0007
		"""
		param = Conversions.value_to_quoted_str(data)
		self._core.io.write(f'SENSe:DDEMod:SEARch:SYNC:DATA {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:SEARch:SYNC:DATA \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.search.sync.data.get() \n
		This command defines the sync sequence of a sync pattern. The pattern must have been selected before using
		[SENSe:]DDEMod:SEARch:SYNC:NAME. Important: The value range of a symbol depends on the degree of modulation,e.g. for an
		8PSK modulation the value range is from 0 to 7. The degree of modulation belongs to the pattern and is set using the
		DDEM:SEAR:SYNC:NST command (see [SENSe:]DDEMod:SEARch:SYNC:NSTate) . \n
			:return: data: Four values represent a symbol (hexadecimal format) . The value range of a symbol depends on the degree of modulation. With a degree of modulation of 4, all symbols have a value range of: 0000, 0001, 0002, 0003 With a degree of modulation of 8: 0000, 0001, 0002, 0003, 0004, 0005, 0006, 0007"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:SYNC:DATA?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def set(self, state: enums.TouchscreenState) -> None:
		"""SCPI: DISPlay:TOUChscreen[:STATe] \n
		Snippet: driver.display.touchscreen.state.set(state = enums.TouchscreenState.FRAMe) \n
		This command controls the touch screen functionality. \n
			:param state: ON | FRAMe | OFF ON | 1 Touch screen is active for entire screen OFF | 0 Touch screen is inactivate for entire screen FRAMe Touch screen is inactivate for the diagram area of the screen, but active for softkeys, toolbars and menus.
		"""
		param = Conversions.enum_scalar_to_str(state, enums.TouchscreenState)
		self._core.io.write(f'DISPlay:TOUChscreen:STATe {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.TouchscreenState:
		"""SCPI: DISPlay:TOUChscreen[:STATe] \n
		Snippet: value: enums.TouchscreenState = driver.display.touchscreen.state.get() \n
		This command controls the touch screen functionality. \n
			:return: state: ON | FRAMe | OFF ON | 1 Touch screen is active for entire screen OFF | 0 Touch screen is inactivate for entire screen FRAMe Touch screen is inactivate for the diagram area of the screen, but active for softkeys, toolbars and menus."""
		response = self._core.io.query_str(f'DISPlay:TOUChscreen:STATe?')
		return Conversions.str_to_scalar_enum(response, enums.TouchscreenState)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AllCls:
	"""All commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("all", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:FILTer[:STATe][:ALL] \n
		Snippet: driver.sense.power.achannel.filterPy.state.all.set(state = False) \n
		No command help available \n
			:param state: No help available
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SENSe:POWer:ACHannel:FILTer:STATe:ALL {param}')



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TypePyCls:
	"""TypePy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("typePy", core, parent)

	def set(self, trace_mode: List[enums.TraceModeA]) -> None:
		"""SCPI: [SENSe]:ADEMod:FM[:TDOMain][:TYPE] \n
		Snippet: driver.sense.ademod.fm.tdomain.typePy.set(trace_mode = [TraceModeA.AVERage, TraceModeA.WRITe]) \n
		No command help available \n
			:param trace_mode: No help available
		"""
		param = Conversions.enum_list_to_str(trace_mode, enums.TraceModeA)
		self._core.io.write(f'SENSe:ADEMod:FM:TDOMain:TYPE {param}')

	# noinspection PyTypeChecker
	def get(self) -> List[enums.TraceModeA]:
		"""SCPI: [SENSe]:ADEMod:FM[:TDOMain][:TYPE] \n
		Snippet: value: List[enums.TraceModeA] = driver.sense.ademod.fm.tdomain.typePy.get() \n
		No command help available \n
			:return: trace_mode: No help available"""
		response = self._core.io.query_str(f'SENSe:ADEMod:FM:TDOMain:TYPE?')
		return Conversions.str_to_list_enum(response, enums.TraceModeA)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	@property
	def next(self):
		"""next commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_next'):
			from .Next import NextCls
			self._next = NextCls(self._core, self._cmd_group)
		return self._next

	def set(self, filename: str) -> None:
		"""SCPI: MMEMory:STORe:STATe \n
		Snippet: driver.massMemory.store.state.set(filename = '1') \n
		This command saves the current instrument configuration in a *.dfl file. \n
			:param filename: String containing the path and name of the target file. The file extension is .dfl.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write_with_opc(f'MMEMory:STORe:STATe 1, {param}')

	def clone(self) -> 'StateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = StateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool, rangePy=repcap.RangePy.Default) -> None:
		"""SCPI: [SENSe]:LIST:RANGe<ri>:INPut:ATTenuation:AUTO \n
		Snippet: driver.sense.listPy.range.inputPy.attenuation.auto.set(state = False, rangePy = repcap.RangePy.Default) \n
		No command help available \n
			:param state: No help available
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
		"""
		param = Conversions.bool_to_str(state)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		self._core.io.write(f'SENSe:LIST:RANGe{rangePy_cmd_val}:INPut:ATTenuation:AUTO {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CalculateCls:
	"""Calculate commands group definition. 212 total commands, 21 Subgroups, 0 group commands
	Repeated Capability: Window, default value after init: Window.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("calculate", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_window_get', 'repcap_window_set', repcap.Window.Nr1)

	def repcap_window_set(self, window: repcap.Window) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Window.Default
		Default value after init: Window.Nr1"""
		self._cmd_group.set_repcap_enum_value(window)

	def repcap_window_get(self) -> repcap.Window:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def bitErrorRate(self):
		"""bitErrorRate commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bitErrorRate'):
			from .BitErrorRate import BitErrorRateCls
			self._bitErrorRate = BitErrorRateCls(self._core, self._cmd_group)
		return self._bitErrorRate

	@property
	def msra(self):
		"""msra commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_msra'):
			from .Msra import MsraCls
			self._msra = MsraCls(self._core, self._cmd_group)
		return self._msra

	@property
	def feed(self):
		"""feed commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_feed'):
			from .Feed import FeedCls
			self._feed = FeedCls(self._core, self._cmd_group)
		return self._feed

	@property
	def formatPy(self):
		"""formatPy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_formatPy'):
			from .FormatPy import FormatPyCls
			self._formatPy = FormatPyCls(self._core, self._cmd_group)
		return self._formatPy

	@property
	def ddem(self):
		"""ddem commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_ddem'):
			from .Ddem import DdemCls
			self._ddem = DdemCls(self._core, self._cmd_group)
		return self._ddem

	@property
	def dlabs(self):
		"""dlabs commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dlabs'):
			from .Dlabs import DlabsCls
			self._dlabs = DlabsCls(self._core, self._cmd_group)
		return self._dlabs

	@property
	def dlRel(self):
		"""dlRel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_dlRel'):
			from .DlRel import DlRelCls
			self._dlRel = DlRelCls(self._core, self._cmd_group)
		return self._dlRel

	@property
	def dsp(self):
		"""dsp commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_dsp'):
			from .Dsp import DspCls
			self._dsp = DspCls(self._core, self._cmd_group)
		return self._dsp

	@property
	def meas(self):
		"""meas commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_meas'):
			from .Meas import MeasCls
			self._meas = MeasCls(self._core, self._cmd_group)
		return self._meas

	@property
	def elin(self):
		"""elin commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_elin'):
			from .Elin import ElinCls
			self._elin = ElinCls(self._core, self._cmd_group)
		return self._elin

	@property
	def fsk(self):
		"""fsk commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_fsk'):
			from .Fsk import FskCls
			self._fsk = FskCls(self._core, self._cmd_group)
		return self._fsk

	@property
	def limit(self):
		"""limit commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_limit'):
			from .Limit import LimitCls
			self._limit = LimitCls(self._core, self._cmd_group)
		return self._limit

	@property
	def marker(self):
		"""marker commands group. 11 Sub-classes, 0 commands."""
		if not hasattr(self, '_marker'):
			from .Marker import MarkerCls
			self._marker = MarkerCls(self._core, self._cmd_group)
		return self._marker

	@property
	def deltaMarker(self):
		"""deltaMarker commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_deltaMarker'):
			from .DeltaMarker import DeltaMarkerCls
			self._deltaMarker = DeltaMarkerCls(self._core, self._cmd_group)
		return self._deltaMarker

	@property
	def statistics(self):
		"""statistics commands group. 3 Sub-classes, 1 commands."""
		if not hasattr(self, '_statistics'):
			from .Statistics import StatisticsCls
			self._statistics = StatisticsCls(self._core, self._cmd_group)
		return self._statistics

	@property
	def tlRel(self):
		"""tlRel commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tlRel'):
			from .TlRel import TlRelCls
			self._tlRel = TlRelCls(self._core, self._cmd_group)
		return self._tlRel

	@property
	def tlAbs(self):
		"""tlAbs commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_tlAbs'):
			from .TlAbs import TlAbsCls
			self._tlAbs = TlAbsCls(self._core, self._cmd_group)
		return self._tlAbs

	@property
	def trace(self):
		"""trace commands group. 3 Sub-classes, 0 commands."""
		if not hasattr(self, '_trace'):
			from .Trace import TraceCls
			self._trace = TraceCls(self._core, self._cmd_group)
		return self._trace

	@property
	def unit(self):
		"""unit commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_unit'):
			from .Unit import UnitCls
			self._unit = UnitCls(self._core, self._cmd_group)
		return self._unit

	@property
	def x(self):
		"""x commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_x'):
			from .X import XCls
			self._x = XCls(self._core, self._cmd_group)
		return self._x

	@property
	def y(self):
		"""y commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_y'):
			from .Y import YCls
			self._y = YCls(self._core, self._cmd_group)
		return self._y

	def clone(self) -> 'CalculateCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CalculateCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FilterPyCls:
	"""FilterPy commands group definition. 2 total commands, 2 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("filterPy", core, parent)

	@property
	def yig(self):
		"""yig commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_yig'):
			from .Yig import YigCls
			self._yig = YigCls(self._core, self._cmd_group)
		return self._yig

	@property
	def hpass(self):
		"""hpass commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_hpass'):
			from .Hpass import HpassCls
			self._hpass = HpassCls(self._core, self._cmd_group)
		return self._hpass

	def clone(self) -> 'FilterPyCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = FilterPyCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SymbolRateCls:
	"""SymbolRate commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("symbolRate", core, parent)

	def set(self, symbol_rate: float) -> None:
		"""SCPI: [SENSe]:DDEMod:SRATe \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.symbolRate.set(symbol_rate = 1.0) \n
		This command defines the symbol rate. The minimum symbol rate is 25 Hz. The maximum symbol rate depends on the defined
		'Sample Rate' (see 'Sample rate, symbol rate and I/Q bandwidth') . \n
			:param symbol_rate: Range: 25 to 250e6, Unit: HZ
		"""
		param = Conversions.decimal_value_to_str(symbol_rate)
		self._core.io.write(f'SENSe:DDEMod:SRATe {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:DDEMod:SRATe \n
		Snippet: value: float = driver.applications.k70Vsa.sense.ddemod.symbolRate.get() \n
		This command defines the symbol rate. The minimum symbol rate is 25 Hz. The maximum symbol rate depends on the defined
		'Sample Rate' (see 'Sample rate, symbol rate and I/Q bandwidth') . \n
			:return: symbol_rate: Range: 25 to 250e6, Unit: HZ"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SRATe?')
		return Conversions.str_to_float(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.AutoManualMode, gapChannel=repcap.GapChannel.Default) -> None:
		"""SCPI: [SENSe]:POWer:ACHannel:GAP<gap>:MODE \n
		Snippet: driver.sense.power.achannel.gap.mode.set(mode = enums.AutoManualMode.AUTO, gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param mode: No help available
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AutoManualMode)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		self._core.io.write(f'SENSe:POWer:ACHannel:GAP{gapChannel_cmd_val}:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, gapChannel=repcap.GapChannel.Default) -> enums.AutoManualMode:
		"""SCPI: [SENSe]:POWer:ACHannel:GAP<gap>:MODE \n
		Snippet: value: enums.AutoManualMode = driver.sense.power.achannel.gap.mode.get(gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: mode: No help available"""
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		response = self._core.io.query_str(f'SENSe:POWer:ACHannel:GAP{gapChannel_cmd_val}:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManualMode)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class MeasurementCls:
	"""Measurement commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("measurement", core, parent)

	def set(self, measurement: enums.Temperature) -> None:
		"""SCPI: [SENSe]:CONFigure:MEASurement \n
		Snippet: driver.applications.k30NoiseFigure.sense.configure.measurement.set(measurement = enums.Temperature.COLD) \n
		This command selects the type of power measurement to perform next. The command is available for manual measurements
		(see[SENSe:]CONFigure:CONTrol ) . \n
			:param measurement: HOT | COLD COLD Performs the Power (Cold) measurement next. HOT Performs the Power (Hot) measurement next.
		"""
		param = Conversions.enum_scalar_to_str(measurement, enums.Temperature)
		self._core.io.write(f'SENSe:CONFigure:MEASurement {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.Temperature:
		"""SCPI: [SENSe]:CONFigure:MEASurement \n
		Snippet: value: enums.Temperature = driver.applications.k30NoiseFigure.sense.configure.measurement.get() \n
		This command selects the type of power measurement to perform next. The command is available for manual measurements
		(see[SENSe:]CONFigure:CONTrol ) . \n
			:return: measurement: HOT | COLD COLD Performs the Power (Cold) measurement next. HOT Performs the Power (Hot) measurement next."""
		response = self._core.io.query_str(f'SENSe:CONFigure:MEASurement?')
		return Conversions.str_to_scalar_enum(response, enums.Temperature)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RlCls:
	"""Rl commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("rl", core, parent)

	def set(self, return_loss: float, window=repcap.Window.Default) -> None:
		"""SCPI: CALCulate<n>:UNCertainty:MATCh:SOURce:RL \n
		Snippet: driver.applications.k30NoiseFigure.calculate.uncertainty.match.source.rl.set(return_loss = 1.0, window = repcap.Window.Default) \n
		This command defines the return loss at the noise source output. If the noise sources during calibration and measurement
		are different, the command defines the uncertainty of the measurement noise source. \n
			:param return_loss: Unit: DB
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
		"""
		param = Conversions.decimal_value_to_str(return_loss)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'CALCulate{window_cmd_val}:UNCertainty:MATCh:SOURce:RL {param}')

	def get(self, window=repcap.Window.Default) -> float:
		"""SCPI: CALCulate<n>:UNCertainty:MATCh:SOURce:RL \n
		Snippet: value: float = driver.applications.k30NoiseFigure.calculate.uncertainty.match.source.rl.get(window = repcap.Window.Default) \n
		This command defines the return loss at the noise source output. If the noise sources during calibration and measurement
		are different, the command defines the uncertainty of the measurement noise source. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: return_loss: Unit: DB"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:UNCertainty:MATCh:SOURce:RL?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PulseCls:
	"""Pulse commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("pulse", core, parent)

	@property
	def period(self):
		"""period commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_period'):
			from .Period import PeriodCls
			self._period = PeriodCls(self._core, self._cmd_group)
		return self._period

	@property
	def trigger(self):
		"""trigger commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_trigger'):
			from .Trigger import TriggerCls
			self._trigger = TriggerCls(self._core, self._cmd_group)
		return self._trigger

	@property
	def width(self):
		"""width commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_width'):
			from .Width import WidthCls
			self._width = WidthCls(self._core, self._cmd_group)
		return self._width

	def clone(self) -> 'PulseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = PulseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TimeCls:
	"""Time commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("time", core, parent)

	@property
	def auto(self):
		"""auto commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_auto'):
			from .Auto import AutoCls
			self._auto = AutoCls(self._core, self._cmd_group)
		return self._auto

	def set(self, time: float) -> None:
		"""SCPI: [SENSe]:SWEep:TIME \n
		Snippet: driver.sense.sweep.time.set(time = 1.0) \n
		This command defines the measurement time. It automatically decouples the time from any other settings. \n
			:param time: refer to data sheet Unit: S
		"""
		param = Conversions.decimal_value_to_str(time)
		self._core.io.write(f'SENSe:SWEep:TIME {param}')

	def get(self) -> float:
		"""SCPI: [SENSe]:SWEep:TIME \n
		Snippet: value: float = driver.sense.sweep.time.get() \n
		This command defines the measurement time. It automatically decouples the time from any other settings. \n
			:return: time: refer to data sheet Unit: S"""
		response = self._core.io.query_str(f'SENSe:SWEep:TIME?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'TimeCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TimeCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, group: enums.DdemGroup) -> None:
		"""SCPI: [SENSe]:DDEMod:PATTern:FORMat \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.pattern.formatPy.set(group = enums.DdemGroup.APSK) \n
		This command selects the pattern demodulation mode. Some modes can only be queried as they are not supported for the two
		modulations feature, but could be set when 'Same as Data Symbols' is selected. \n
			:param group: MSK | PSK | QAM | QPSK | FSK | ASK | APSK | UQAM
		"""
		param = Conversions.enum_scalar_to_str(group, enums.DdemGroup)
		self._core.io.write(f'SENSe:DDEMod:PATTern:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.DdemGroup:
		"""SCPI: [SENSe]:DDEMod:PATTern:FORMat \n
		Snippet: value: enums.DdemGroup = driver.applications.k70Vsa.sense.ddemod.pattern.formatPy.get() \n
		This command selects the pattern demodulation mode. Some modes can only be queried as they are not supported for the two
		modulations feature, but could be set when 'Same as Data Symbols' is selected. \n
			:return: group: MSK | PSK | QAM | QPSK | FSK | ASK | APSK | UQAM"""
		response = self._core.io.query_str(f'SENSe:DDEMod:PATTern:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.DdemGroup)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from .....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class IntervalCls:
	"""Interval commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("interval", core, parent)

	def set(self, interval: str) -> None:
		"""SCPI: DIAGnostic:SERVice:CALibration:INTerval \n
		Snippet: driver.diagnostic.service.calibration.interval.set(interval = '1') \n
		This command queries the recommended calibration interval (ISO 8601 duration) . \n
			:param interval: String containing the recommended calibration interval.
		"""
		param = Conversions.value_to_quoted_str(interval)
		self._core.io.write(f'DIAGnostic:SERVice:CALibration:INTerval {param}')

	def get(self) -> str:
		"""SCPI: DIAGnostic:SERVice:CALibration:INTerval \n
		Snippet: value: str = driver.diagnostic.service.calibration.interval.get() \n
		This command queries the recommended calibration interval (ISO 8601 duration) . \n
			:return: interval: String containing the recommended calibration interval."""
		response = self._core.io.query_str(f'DIAGnostic:SERVice:CALibration:INTerval?')
		return trim_str_response(response)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class BorderingCls:
	"""Bordering commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("bordering", core, parent)

	def set(self, bit_ordering: enums.BitOrdering) -> None:
		"""SCPI: [SENSe]:DDEMod:BORDering \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.bordering.set(bit_ordering = enums.BitOrdering.LSB) \n
		Determines how the bits in the symbols are ordered in all symbol displays. \n
			:param bit_ordering: MSB | LSB LSB Least-significant bit first (used in Bluetooth specification, for example) MSB Most significant bit first (default)
		"""
		param = Conversions.enum_scalar_to_str(bit_ordering, enums.BitOrdering)
		self._core.io.write(f'SENSe:DDEMod:BORDering {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.BitOrdering:
		"""SCPI: [SENSe]:DDEMod:BORDering \n
		Snippet: value: enums.BitOrdering = driver.applications.k70Vsa.sense.ddemod.bordering.get() \n
		Determines how the bits in the symbols are ordered in all symbol displays. \n
			:return: bit_ordering: MSB | LSB LSB Least-significant bit first (used in Bluetooth specification, for example) MSB Most significant bit first (default)"""
		response = self._core.io.query_str(f'SENSe:DDEMod:BORDering?')
		return Conversions.str_to_scalar_enum(response, enums.BitOrdering)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal.Types import DataType
from .....Internal.ArgSingleList import ArgSingleList
from .....Internal.ArgSingle import ArgSingle
from .....Internal.RepeatedCapability import RepeatedCapability
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TraceCls:
	"""Trace commands group definition. 2 total commands, 1 Subgroups, 1 group commands
	Repeated Capability: Window, default value after init: Window.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("trace", core, parent)
		self._cmd_group.rep_cap = RepeatedCapability(self._cmd_group.group_name, 'repcap_window_get', 'repcap_window_set', repcap.Window.Nr1)

	def repcap_window_set(self, window: repcap.Window) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Window.Default
		Default value after init: Window.Nr1"""
		self._cmd_group.set_repcap_enum_value(window)

	def repcap_window_get(self) -> repcap.Window:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._cmd_group.get_repcap_enum_value()

	@property
	def data(self):
		"""data commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_data'):
			from .Data import DataCls
			self._data = DataCls(self._core, self._cmd_group)
		return self._data

	def copy(self, target_trace: enums.TraceTypeNumeric, source_trace: enums.TraceTypeNumeric, window=repcap.Window.Default) -> None:
		"""SCPI: TRACe<n>:COPY \n
		Snippet: driver.applications.k40PhaseNoise.trace.copy(target_trace = enums.TraceTypeNumeric.TRACe1, source_trace = enums.TraceTypeNumeric.TRACe1, window = repcap.Window.Default) \n
		This command copies data from one trace to another. \n
			:param target_trace: No help available
			:param source_trace: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trace')
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('target_trace', target_trace, DataType.Enum, enums.TraceTypeNumeric), ArgSingle('source_trace', source_trace, DataType.Enum, enums.TraceTypeNumeric))
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write_with_opc(f'TRACe{window_cmd_val}:COPY {param}'.rstrip())

	def clone(self) -> 'TraceCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = TraceCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class HarmonicsCls:
	"""Harmonics commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("harmonics", core, parent)

	@property
	def identify(self):
		"""identify commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_identify'):
			from .Identify import IdentifyCls
			self._identify = IdentifyCls(self._core, self._cmd_group)
		return self._identify

	@property
	def mnumber(self):
		"""mnumber commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mnumber'):
			from .Mnumber import MnumberCls
			self._mnumber = MnumberCls(self._core, self._cmd_group)
		return self._mnumber

	@property
	def tolerance(self):
		"""tolerance commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_tolerance'):
			from .Tolerance import ToleranceCls
			self._tolerance = ToleranceCls(self._core, self._cmd_group)
		return self._tolerance

	def clone(self) -> 'HarmonicsCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = HarmonicsCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AbsCls:
	"""Abs commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("abs", core, parent)

	def set(self, level: float, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default, limitIx=repcap.LimitIx.Default) -> None:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:LIMit<li>:RELative:STARt:ABS \n
		Snippet: driver.sense.espectrum.range.limit.relative.start.abs.set(level = 1.0, subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default, limitIx = repcap.LimitIx.Default) \n
		No command help available \n
			:param level: No help available
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
		"""
		param = Conversions.decimal_value_to_str(level)
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		self._core.io.write(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit{limitIx_cmd_val}:RELative:STARt:ABS {param}')

	def get(self, subBlock=repcap.SubBlock.Default, rangePy=repcap.RangePy.Default, limitIx=repcap.LimitIx.Default) -> float:
		"""SCPI: [SENSe]:ESPectrum<sb>:RANGe<ri>:LIMit<li>:RELative:STARt:ABS \n
		Snippet: value: float = driver.sense.espectrum.range.limit.relative.start.abs.get(subBlock = repcap.SubBlock.Default, rangePy = repcap.RangePy.Default, limitIx = repcap.LimitIx.Default) \n
		No command help available \n
			:param subBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Espectrum')
			:param rangePy: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Range')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:return: level: No help available"""
		subBlock_cmd_val = self._cmd_group.get_repcap_cmd_value(subBlock, repcap.SubBlock)
		rangePy_cmd_val = self._cmd_group.get_repcap_cmd_value(rangePy, repcap.RangePy)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		response = self._core.io.query_str(f'SENSe:ESPectrum{subBlock_cmd_val}:RANGe{rangePy_cmd_val}:LIMit{limitIx_cmd_val}:RELative:STARt:ABS?')
		return Conversions.str_to_float(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, qpsk_format: enums.QpskFormat) -> None:
		"""SCPI: [SENSe]:DDEMod:QPSK:FORMat \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.qpsk.formatPy.set(qpsk_format = enums.QpskFormat.DIFFerential) \n
		This command defines the demodulation order for QPSK. \n
			:param qpsk_format: NORMal | DIFFerential | NPI4 | DPI4 | OFFSet | SOFFset | N3Pi4 NORMal Demodulation order QPSK is used. DIFFerential Demodulation order DQPSK is used. NPI4 Demodulation order π/4 QPSK is used. DPI4 Demodulation order π/4 DQPSK is used. OFFSet Demodulation order OQPSK is used. N3PI4 Demodulation order 3π/4 QPSK is used. SOFFset Shaped Offset QPSK
		"""
		param = Conversions.enum_scalar_to_str(qpsk_format, enums.QpskFormat)
		self._core.io.write(f'SENSe:DDEMod:QPSK:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.QpskFormat:
		"""SCPI: [SENSe]:DDEMod:QPSK:FORMat \n
		Snippet: value: enums.QpskFormat = driver.applications.k70Vsa.sense.ddemod.qpsk.formatPy.get() \n
		This command defines the demodulation order for QPSK. \n
			:return: qpsk_format: NORMal | DIFFerential | NPI4 | DPI4 | OFFSet | SOFFset | N3Pi4 NORMal Demodulation order QPSK is used. DIFFerential Demodulation order DQPSK is used. NPI4 Demodulation order π/4 QPSK is used. DPI4 Demodulation order π/4 DQPSK is used. OFFSet Demodulation order OQPSK is used. N3PI4 Demodulation order 3π/4 QPSK is used. SOFFset Shaped Offset QPSK"""
		response = self._core.io.query_str(f'SENSe:DDEMod:QPSK:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.QpskFormat)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StateCls:
	"""State commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("state", core, parent)

	def get(self, step=repcap.Step.Default) -> bool:
		"""SCPI: SYSTem:COMMunicate:RDEVice:OSCilloscope:ALIGnment:STEP<1|2>[:STATe] \n
		Snippet: value: bool = driver.system.communicate.rdevice.oscilloscope.alignment.step.state.get(step = repcap.Step.Default) \n
		No command help available \n
			:param step: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Step')
			:return: alignment_step: No help available"""
		step_cmd_val = self._cmd_group.get_repcap_cmd_value(step, repcap.Step)
		response = self._core.io.query_str(f'SYSTem:COMMunicate:RDEVice:OSCilloscope:ALIGnment:STEP{step_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class FormatPyCls:
	"""FormatPy commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("formatPy", core, parent)

	def set(self, format_py: enums.TimeFormat, window=repcap.Window.Default) -> None:
		"""SCPI: DISPlay[:WINDow<n>]:TIME:FORMat \n
		Snippet: driver.display.window.time.formatPy.set(format_py = enums.TimeFormat.DE, window = repcap.Window.Default) \n
		This command selects the time and date format. \n
			:param format_py: US | DE | ISO DE dd.mm.yyyy hh:mm:ss 24 hour format. US mm/dd/yyyy hh:mm:ss 12 hour format. ISO yyyy-mm-dd hh:mm:ss 24 hour format.
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.TimeFormat)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		self._core.io.write(f'DISPlay:WINDow{window_cmd_val}:TIME:FORMat {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default) -> enums.TimeFormat:
		"""SCPI: DISPlay[:WINDow<n>]:TIME:FORMat \n
		Snippet: value: enums.TimeFormat = driver.display.window.time.formatPy.get(window = repcap.Window.Default) \n
		This command selects the time and date format. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Window')
			:return: format_py: US | DE | ISO DE dd.mm.yyyy hh:mm:ss 24 hour format. US mm/dd/yyyy hh:mm:ss 12 hour format. ISO yyyy-mm-dd hh:mm:ss 24 hour format."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'DISPlay:WINDow{window_cmd_val}:TIME:FORMat?')
		return Conversions.str_to_scalar_enum(response, enums.TimeFormat)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ValueCls:
	"""Value commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("value", core, parent)

	def set(self, trace_ref_type: enums.TraceRefType, window=repcap.Window.Default, trace=repcap.Trace.Default) -> None:
		"""SCPI: CALCulate<n>:TRACe<t>[:VALue] \n
		Snippet: driver.applications.k70Vsa.calculate.trace.value.set(trace_ref_type = enums.TraceRefType.ERRor, window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This commands selects the signal to be used as the data source for a trace. For method RsFswp.Display.Window.Subwindow.
		Trace.Mode.set View, the data source to be evaluated cannot be changed. It remains set to the value that was most
		recently set. \n
			:param trace_ref_type: MEAS | REF | ERRor | TCAP MEAS Measurement signal REF Reference signal ERR Error TCAP Capture buffer
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
		"""
		param = Conversions.enum_scalar_to_str(trace_ref_type, enums.TraceRefType)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		self._core.io.write(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:VALue {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, trace=repcap.Trace.Default) -> enums.TraceRefType:
		"""SCPI: CALCulate<n>:TRACe<t>[:VALue] \n
		Snippet: value: enums.TraceRefType = driver.applications.k70Vsa.calculate.trace.value.get(window = repcap.Window.Default, trace = repcap.Trace.Default) \n
		This commands selects the signal to be used as the data source for a trace. For method RsFswp.Display.Window.Subwindow.
		Trace.Mode.set View, the data source to be evaluated cannot be changed. It remains set to the value that was most
		recently set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param trace: optional repeated capability selector. Default value: Tr1 (settable in the interface 'Trace')
			:return: trace_ref_type: MEAS | REF | ERRor | TCAP MEAS Measurement signal REF Reference signal ERR Error TCAP Capture buffer"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		trace_cmd_val = self._cmd_group.get_repcap_cmd_value(trace, repcap.Trace)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:TRACe{trace_cmd_val}:VALue?')
		return Conversions.str_to_scalar_enum(response, enums.TraceRefType)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StandardCls:
	"""Standard commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("standard", core, parent)

	def set(self, standard: enums.TechnologyStandardDdem) -> None:
		"""SCPI: [SENSe]:DDEMod:PRESet[:STANdard] \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.preset.standard.set(standard = enums.TechnologyStandardDdem.DECT) \n
		This command selects an automatic setting of all modulation parameters according to a standardized transmission method or
		a user-defined transmission method. The standardized transmission methods are available in the instrument as predefined
		standards. \n
			:param standard: (enum or string) Specifies the file name that contains the transmission method without the extension. For user-defined standards, the file path must be included. Default standards predefined by Rohde&Schwarz do not require a path definition. A list of predefined standards (including short forms) is provided in the annex (see 'Predefined standards and settings') .
		"""
		param = Conversions.enum_ext_scalar_to_str(standard, enums.TechnologyStandardDdem)
		self._core.io.write(f'SENSe:DDEMod:PRESet:STANdard {param}')

	# noinspection PyTypeChecker
	def get(self) -> enums.TechnologyStandardDdem:
		"""SCPI: [SENSe]:DDEMod:PRESet[:STANdard] \n
		Snippet: value: enums.TechnologyStandardDdem = driver.applications.k70Vsa.sense.ddemod.preset.standard.get() \n
		This command selects an automatic setting of all modulation parameters according to a standardized transmission method or
		a user-defined transmission method. The standardized transmission methods are available in the instrument as predefined
		standards. \n
			:return: standard: (enum or string) Specifies the file name that contains the transmission method without the extension. For user-defined standards, the file path must be included. Default standards predefined by Rohde&Schwarz do not require a path definition. A list of predefined standards (including short forms) is provided in the annex (see 'Predefined standards and settings') ."""
		response = self._core.io.query_str(f'SENSe:DDEMod:PRESet:STANdard?')
		return Conversions.str_to_scalar_enum_ext(response, enums.TechnologyStandardDdem)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AddCls:
	"""Add commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("add", core, parent)

	def set(self, component=repcap.Component.Default) -> None:
		"""SCPI: [SENSe]:FPLan:COMPonent<co>:ADD \n
		Snippet: driver.applications.k50Spurious.sense.fplan.component.add.set(component = repcap.Component.Default) \n
		Adds a new component below the selected row <co> in the frequency plan. If the command is executed on a row that does not
		yet exist, this row and all that are missing up to this row are created. \n
			:param component: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Component')
		"""
		component_cmd_val = self._cmd_group.get_repcap_cmd_value(component, repcap.Component)
		self._core.io.write(f'SENSe:FPLan:COMPonent{component_cmd_val}:ADD')

	def set_with_opc(self, component=repcap.Component.Default, opc_timeout_ms: int = -1) -> None:
		component_cmd_val = self._cmd_group.get_repcap_cmd_value(component, repcap.Component)
		"""SCPI: [SENSe]:FPLan:COMPonent<co>:ADD \n
		Snippet: driver.applications.k50Spurious.sense.fplan.component.add.set_with_opc(component = repcap.Component.Default) \n
		Adds a new component below the selected row <co> in the frequency plan. If the command is executed on a row that does not
		yet exist, this row and all that are missing up to this row are created. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsFswp.utilities.opc_timeout_set() to set the timeout value. \n
			:param component: optional repeated capability selector. Default value: Ix1 (settable in the interface 'Component')
			:param opc_timeout_ms: Maximum time to wait in milliseconds, valid only for this call."""
		self._core.io.write_with_opc(f'SENSe:FPLan:COMPonent{component_cmd_val}:ADD', opc_timeout_ms)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TpiSampleCls:
	"""TpiSample commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("tpiSample", core, parent)

	def get(self) -> float:
		"""SCPI: TRACe:IQ:TPISample \n
		Snippet: value: float = driver.applications.iqAnalyzer.trace.iq.tpiSample.get() \n
		This command queries the time offset between the sample start and the trigger event (trigger point in sample = TPIS) .
		Since the R&S FSWP usually samples with a much higher sample rate than the specific application actually requires, the
		trigger point determined internally is much more precise than the one determined from the (downsampled) data in the
		application. Thus, the TPIS indicates the offset between the sample start and the actual trigger event. This value can
		only be determined in triggered measurements using external or IFPower triggers, otherwise the value is 0. \n
			:return: tpis: numeric value Unit: s"""
		response = self._core.io.query_str(f'TRACe:IQ:TPISample?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SenseCls:
	"""Sense commands group definition. 142 total commands, 7 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("sense", core, parent)

	@property
	def swapIq(self):
		"""swapIq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_swapIq'):
			from .SwapIq import SwapIqCls
			self._swapIq = SwapIqCls(self._core, self._cmd_group)
		return self._swapIq

	@property
	def frequency(self):
		"""frequency commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import FrequencyCls
			self._frequency = FrequencyCls(self._core, self._cmd_group)
		return self._frequency

	@property
	def ddemod(self):
		"""ddemod commands group. 32 Sub-classes, 0 commands."""
		if not hasattr(self, '_ddemod'):
			from .Ddemod import DdemodCls
			self._ddemod = DdemodCls(self._core, self._cmd_group)
		return self._ddemod

	@property
	def msra(self):
		"""msra commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_msra'):
			from .Msra import MsraCls
			self._msra = MsraCls(self._core, self._cmd_group)
		return self._msra

	@property
	def sweep(self):
		"""sweep commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_sweep'):
			from .Sweep import SweepCls
			self._sweep = SweepCls(self._core, self._cmd_group)
		return self._sweep

	@property
	def adjust(self):
		"""adjust commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_adjust'):
			from .Adjust import AdjustCls
			self._adjust = AdjustCls(self._core, self._cmd_group)
		return self._adjust

	@property
	def tcapture(self):
		"""tcapture commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_tcapture'):
			from .Tcapture import TcaptureCls
			self._tcapture = TcaptureCls(self._core, self._cmd_group)
		return self._tcapture

	def clone(self) -> 'SenseCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SenseCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CommentCls:
	"""Comment commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("comment", core, parent)

	def set(self, comment: str) -> None:
		"""SCPI: [SENSe]:DDEMod:STANdard:COMMent \n
		Snippet: driver.applications.k70Vsa.sense.ddemod.standard.comment.set(comment = '1') \n
		This command enters the comment for a new standard. The comment is stored with the standard and is only displayed in the
		selection menu (manual operation) . In remote control, the string is deleted after the standard has been stored, allowing
		a new comment to be entered for the next standard. In this case a blank string is returned when for the query. \n
			:param comment: No help available
		"""
		param = Conversions.value_to_quoted_str(comment)
		self._core.io.write(f'SENSe:DDEMod:STANdard:COMMent {param}')

	def get(self) -> str:
		"""SCPI: [SENSe]:DDEMod:STANdard:COMMent \n
		Snippet: value: str = driver.applications.k70Vsa.sense.ddemod.standard.comment.get() \n
		This command enters the comment for a new standard. The comment is stored with the standard and is only displayed in the
		selection menu (manual operation) . In remote control, the string is deleted after the standard has been stored, allowing
		a new comment to be entered for the next standard. In this case a blank string is returned when for the query. \n
			:return: comment: No help available"""
		response = self._core.io.query_str(f'SENSe:DDEMod:STANdard:COMMent?')
		return trim_str_response(response)



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions
from ...Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DestinationCls:
	"""Destination commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("destination", core, parent)

	def set(self, destination: str) -> None:
		"""SCPI: HCOPy:DESTination \n
		Snippet: driver.hardCopy.destination.set(destination = '1') \n
		This command selects the destination of a print job. Note: To print a screenshot to a file, see method RsFswp.HardCopy.
		Device.Language.set. \n
			:param destination: 'MMEM' Activates 'Print to file'. Thus, if the destination of the print function is set to 'printer' (see HCOP:DEST1 'SYSTem:COMMunicate:PRINter' or HCOP:DEV:LANG GDI) , the output is redirected to a .PRN file using the selected printer driver. Select the file name with method RsFswp.MassMemory.Name.set. Note: To save a screenshot to a file, see method RsFswp.HardCopy.Device.Language.set. 'SYSTem:COMMunicate:PRINter' Sends the hardcopy to a printer and deactivates 'print to file'. Select the printer with SYSTem:COMMunicate:PRINter:SELectdi . 'SYSTem:COMMunicate:CLIPboard' Sends the hardcopy to the clipboard.
		"""
		param = Conversions.value_to_quoted_str(destination)
		self._core.io.write(f'HCOPy:DESTination {param}')

	def get(self) -> str:
		"""SCPI: HCOPy:DESTination \n
		Snippet: value: str = driver.hardCopy.destination.get() \n
		This command selects the destination of a print job. Note: To print a screenshot to a file, see method RsFswp.HardCopy.
		Device.Language.set. \n
			:return: destination: 'MMEM' Activates 'Print to file'. Thus, if the destination of the print function is set to 'printer' (see HCOP:DEST1 'SYSTem:COMMunicate:PRINter' or HCOP:DEV:LANG GDI) , the output is redirected to a .PRN file using the selected printer driver. Select the file name with method RsFswp.MassMemory.Name.set. Note: To save a screenshot to a file, see method RsFswp.HardCopy.Device.Language.set. 'SYSTem:COMMunicate:PRINter' Sends the hardcopy to a printer and deactivates 'print to file'. Select the printer with SYSTem:COMMunicate:PRINter:SELectdi . 'SYSTem:COMMunicate:CLIPboard' Sends the hardcopy to the clipboard."""
		response = self._core.io.query_str(f'HCOPy:DESTination?')
		return trim_str_response(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CatalogCls:
	"""Catalog commands group definition. 2 total commands, 1 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("catalog", core, parent)

	@property
	def long(self):
		"""long commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_long'):
			from .Long import LongCls
			self._long = LongCls(self._core, self._cmd_group)
		return self._long

	def get(self) -> str:
		"""SCPI: MMEMory:CATalog \n
		Snippet: value: str = driver.massMemory.catalog.get() \n
		This command returns the contents of a particular directory. \n
			:return: filename: String containing the path and directory If you leave out the path, the command returns the contents of the directory selected with method RsFswp.MassMemory.CurrentDirectory.set. The path may be relative or absolute. Using wildcards ('*') is possible to query a certain type of files only. If you use a specific file as a parameter, the command returns the name of the file if the file is found in the specified directory, or an error if the file is not found ('-256,'File name not found') ."""
		response = self._core.io.query_str(f'MMEMory:CATalog?')
		return trim_str_response(response)

	def clone(self) -> 'CatalogCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = CatalogCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.Types import DataType
from ......Internal.StructBase import StructBase
from ......Internal.ArgStruct import ArgStruct
from ......Internal.ArgSingleList import ArgSingleList
from ......Internal.ArgSingle import ArgSingle


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SettingsCls:
	"""Settings commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("settings", core, parent)

	def set(self, frequency: List[float] = None, search_span: List[float] = None, det_threshold: List[float] = None, desired_spur_snr: List[float] = None) -> None:
		"""SCPI: [SENSe]:DIRected:SETTings \n
		Snippet: driver.applications.k50Spurious.sense.directed.settings.set(frequency = [1.1, 2.2, 3.3], search_span = [1.1, 2.2, 3.3], det_threshold = [1.1, 2.2, 3.3], desired_spur_snr = [1.1, 2.2, 3.3]) \n
		Defines the current directed search configuration, that is: all frequency spans to be measured in detail. The current
		configuration table is overwritten. Note that all entries must be defined in one command so that the R&S FSWP Spurious
		measurements application can detect any possible conflicts between the frequency spans. The parameters are defined as a
		comma-separated list with one line per span, using the following syntax: <Frequency>,<SearchSpan>,<DetThreshold>,<SNR>
		For details on the parameters see 'Directed Search Measurement settings') . \n
			:param frequency: numeric value Center frequency for directed search measurement of the spur Unit: HZ
			:param search_span: numeric value The span around the frequency for which a detailed measurement (spurious detection sweep and spot search) is performed. Note that the frequency spans must be distinct, that is: they may not overlap. Unit: HZ
			:param det_threshold: numeric value Absolute threshold that the power level must exceed for a spur to be detected. Unit: dBm
			:param desired_spur_snr: numeric value Minimum signal-to-noise ratio that the power level must exceed for a spur to be detected during the spot search Unit: dB
		"""
		param = ArgSingleList().compose_cmd_string(ArgSingle('frequency', frequency, DataType.FloatList, None, True, True, 1), ArgSingle('search_span', search_span, DataType.FloatList, None, True, True, 1), ArgSingle('det_threshold', det_threshold, DataType.FloatList, None, True, True, 1), ArgSingle('desired_spur_snr', desired_spur_snr, DataType.FloatList, None, True, True, 1))
		self._core.io.write(f'SENSe:DIRected:SETTings {param}'.rstrip())

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Search_Span: List[float]: numeric value The span around the frequency for which a detailed measurement (spurious detection sweep and spot search) is performed. Note that the frequency spans must be distinct, that is: they may not overlap. Unit: HZ
			- Det_Threshold: List[float]: numeric value Absolute threshold that the power level must exceed for a spur to be detected. Unit: dBm
			- Desired_Spur_Snr: List[float]: numeric value Minimum signal-to-noise ratio that the power level must exceed for a spur to be detected during the spot search Unit: dB"""
		__meta_args_list = [
			ArgStruct('Search_Span', DataType.FloatList, None, False, True, 1),
			ArgStruct('Det_Threshold', DataType.FloatList, None, False, True, 1),
			ArgStruct('Desired_Spur_Snr', DataType.FloatList, None, False, True, 1)]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Search_Span: List[float] = None
			self.Det_Threshold: List[float] = None
			self.Desired_Spur_Snr: List[float] = None

	def get(self) -> GetStruct:
		"""SCPI: [SENSe]:DIRected:SETTings \n
		Snippet: value: GetStruct = driver.applications.k50Spurious.sense.directed.settings.get() \n
		Defines the current directed search configuration, that is: all frequency spans to be measured in detail. The current
		configuration table is overwritten. Note that all entries must be defined in one command so that the R&S FSWP Spurious
		measurements application can detect any possible conflicts between the frequency spans. The parameters are defined as a
		comma-separated list with one line per span, using the following syntax: <Frequency>,<SearchSpan>,<DetThreshold>,<SNR>
		For details on the parameters see 'Directed Search Measurement settings') . \n
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		return self._core.io.query_struct(f'SENSe:DIRected:SETTings?', self.__class__.GetStruct())



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class GeneratorCls:
	"""Generator commands group definition. 3 total commands, 3 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("generator", core, parent)

	@property
	def interface(self):
		"""interface commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_interface'):
			from .Interface import InterfaceCls
			self._interface = InterfaceCls(self._core, self._cmd_group)
		return self._interface

	@property
	def link(self):
		"""link commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_link'):
			from .Link import LinkCls
			self._link = LinkCls(self._core, self._cmd_group)
		return self._link

	@property
	def typePy(self):
		"""typePy commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_typePy'):
			from .TypePy import TypePyCls
			self._typePy = TypePyCls(self._core, self._cmd_group)
		return self._typePy

	def clone(self) -> 'GeneratorCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = GeneratorCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class YCls:
	"""Y commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("y", core, parent)

	def get(self, window=repcap.Window.Default, marker=repcap.Marker.Default) -> float:
		"""SCPI: CALCulate<n>:MARKer<m>:FUNCtion:FPEaks:Y \n
		Snippet: value: float = driver.calculate.marker.function.fpeaks.y.get(window = repcap.Window.Default, marker = repcap.Marker.Default) \n
		This command queries the position of the peaks on the y-axis. The order depends on the sort order that has been set with
		method RsFswp.Calculate.Marker.Function.Fpeaks.Sort.set. \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param marker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Marker')
			:return: peak_position: Position of the peaks on the y-axis. The unit depends on the measurement."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		marker_cmd_val = self._cmd_group.get_repcap_cmd_value(marker, repcap.Marker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:MARKer{marker_cmd_val}:FUNCtion:FPEaks:Y?')
		return Conversions.str_to_float(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, window_name: enums.WindowName, outputConnector=repcap.OutputConnector.Default) -> None:
		"""SCPI: OUTPut<up>:ADEMod[:ONLine]:SOURce \n
		Snippet: driver.output.ademod.online.source.set(window_name = enums.WindowName.FOCus, outputConnector = repcap.OutputConnector.Default) \n
		This command selects the result display whose results are output. Only active time domain results can be selected. \n
			:param window_name: (enum or string) string String containing the name of the window. By default, the name of a window is the same as its index. To determine the name and index of all active windows, use the method RsFswp.Layout.Catalog.Window.get_ query. FOCus Dynamically switches to the currently selected window. If a window is selected that does not contain a time-domain result display, the selection is ignored and the previous setting is maintained.
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
		"""
		param = Conversions.enum_ext_scalar_to_str(window_name, enums.WindowName)
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		self._core.io.write(f'OUTPut{outputConnector_cmd_val}:ADEMod:ONLine:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self, outputConnector=repcap.OutputConnector.Default) -> enums.WindowName:
		"""SCPI: OUTPut<up>:ADEMod[:ONLine]:SOURce \n
		Snippet: value: enums.WindowName = driver.output.ademod.online.source.get(outputConnector = repcap.OutputConnector.Default) \n
		This command selects the result display whose results are output. Only active time domain results can be selected. \n
			:param outputConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Output')
			:return: window_name: (enum or string) string String containing the name of the window. By default, the name of a window is the same as its index. To determine the name and index of all active windows, use the method RsFswp.Layout.Catalog.Window.get_ query. FOCus Dynamically switches to the currently selected window. If a window is selected that does not contain a time-domain result display, the selection is ignored and the previous setting is maintained."""
		outputConnector_cmd_val = self._cmd_group.get_repcap_cmd_value(outputConnector, repcap.OutputConnector)
		response = self._core.io.query_str(f'OUTPut{outputConnector_cmd_val}:ADEMod:ONLine:SOURce?')
		return Conversions.str_to_scalar_enum_ext(response, enums.WindowName)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ModeCls:
	"""Mode commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("mode", core, parent)

	def set(self, mode: enums.MarkerMode, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> None:
		"""SCPI: CALCulate<n>:DELTamarker<m>:FUNCtion:BPOWer:MODE \n
		Snippet: driver.calculate.deltaMarker.function.bpower.mode.set(mode = enums.MarkerMode.DENSity, window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		No command help available \n
			:param mode: No help available
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.MarkerMode)
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		self._core.io.write(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:FUNCtion:BPOWer:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, window=repcap.Window.Default, deltaMarker=repcap.DeltaMarker.Default) -> enums.MarkerMode:
		"""SCPI: CALCulate<n>:DELTamarker<m>:FUNCtion:BPOWer:MODE \n
		Snippet: value: enums.MarkerMode = driver.calculate.deltaMarker.function.bpower.mode.get(window = repcap.Window.Default, deltaMarker = repcap.DeltaMarker.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param deltaMarker: optional repeated capability selector. Default value: Nr1 (settable in the interface 'DeltaMarker')
			:return: mode: No help available"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		deltaMarker_cmd_val = self._cmd_group.get_repcap_cmd_value(deltaMarker, repcap.DeltaMarker)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:DELTamarker{deltaMarker_cmd_val}:FUNCtion:BPOWer:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.MarkerMode)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SamplesCls:
	"""Samples commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("samples", core, parent)

	def get(self) -> int:
		"""SCPI: [SENSe]:DDEMod:SEARch:MBURst:STARt:SAMPles \n
		Snippet: value: int = driver.applications.k70Vsa.sense.ddemod.search.mburst.start.samples.get() \n
		This command queries the start sample of the current result range within the capture buffer. Tip: to query the start
		symbol, use [SENSe:]DDEMod:SEARch:MBURst:STARt[:SYMBols]?. \n
			:return: start: No help available"""
		response = self._core.io.query_str(f'SENSe:DDEMod:SEARch:MBURst:STARt:SAMPles?')
		return Conversions.str_to_int(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ImpedanceCls:
	"""Impedance commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("impedance", core, parent)

	def set(self, impedance: int, inputIx=repcap.InputIx.Default) -> None:
		"""SCPI: INPut<ip>:IMPedance \n
		Snippet: driver.applications.k30NoiseFigure.inputPy.impedance.set(impedance = 1, inputIx = repcap.InputIx.Default) \n
		This command selects the nominal input impedance of the RF input. In some applications, only 50 Ω are supported. \n
			:param impedance: 50 | 75 Unit: OHM
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
		"""
		param = Conversions.decimal_value_to_str(impedance)
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		self._core.io.write(f'INPut{inputIx_cmd_val}:IMPedance {param}')

	def get(self, inputIx=repcap.InputIx.Default) -> int:
		"""SCPI: INPut<ip>:IMPedance \n
		Snippet: value: int = driver.applications.k30NoiseFigure.inputPy.impedance.get(inputIx = repcap.InputIx.Default) \n
		This command selects the nominal input impedance of the RF input. In some applications, only 50 Ω are supported. \n
			:param inputIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'InputPy')
			:return: impedance: 50 | 75 Unit: OHM"""
		inputIx_cmd_val = self._cmd_group.get_repcap_cmd_value(inputIx, repcap.InputIx)
		response = self._core.io.query_str(f'INPut{inputIx_cmd_val}:IMPedance?')
		return Conversions.str_to_int(response)



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class DexportCls:
	"""Dexport commands group definition. 4 total commands, 4 Subgroups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("dexport", core, parent)

	@property
	def xdistrib(self):
		"""xdistrib commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_xdistrib'):
			from .Xdistrib import XdistribCls
			self._xdistrib = XdistribCls(self._core, self._cmd_group)
		return self._xdistrib

	@property
	def dseparator(self):
		"""dseparator commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dseparator'):
			from .Dseparator import DseparatorCls
			self._dseparator = DseparatorCls(self._core, self._cmd_group)
		return self._dseparator

	@property
	def header(self):
		"""header commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_header'):
			from .Header import HeaderCls
			self._header = HeaderCls(self._core, self._cmd_group)
		return self._header

	@property
	def traces(self):
		"""traces commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_traces'):
			from .Traces import TracesCls
			self._traces = TracesCls(self._core, self._cmd_group)
		return self._traces

	def clone(self) -> 'DexportCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = DexportCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CountCls:
	"""Count commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("count", core, parent)

	def get(self, window=repcap.Window.Default) -> int:
		"""SCPI: CALCulate<n>:SPECtrogram:FRAMe:COUNt \n
		Snippet: value: int = driver.applications.k60Transient.calculate.spectrogram.frame.count.get(window = repcap.Window.Default) \n
		This command queries the number of frames that are contained in the selected result display (depends on the evaluation
		basis) . \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:return: frames: The maximum number of frames depends on the history depth. Range: 1 to history depth"""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		response = self._core.io.query_str(f'CALCulate{window_cmd_val}:SPECtrogram:FRAMe:COUNt?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AmplitudeCls:
	"""Amplitude commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("amplitude", core, parent)

	def set(self, voltage: float) -> None:
		"""SCPI: SOURce:VOLTage:AUX:LEVel:AMPLitude \n
		Snippet: driver.applications.k30NoiseFigure.source.voltage.auxiliary.level.amplitude.set(voltage = 1.0) \n
		No command help available \n
			:param voltage: No help available
		"""
		param = Conversions.decimal_value_to_str(voltage)
		self._core.io.write(f'SOURce:VOLTage:AUX:LEVel:AMPLitude {param}')

	def get(self) -> float:
		"""SCPI: SOURce:VOLTage:AUX:LEVel:AMPLitude \n
		Snippet: value: float = driver.applications.k30NoiseFigure.source.voltage.auxiliary.level.amplitude.get() \n
		No command help available \n
			:return: voltage: No help available"""
		response = self._core.io.query_str(f'SOURce:VOLTage:AUX:LEVel:AMPLitude?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.StructBase import StructBase
from ........Internal.ArgStruct import ArgStruct
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class ResultCls:
	"""Result commands group definition. 3 total commands, 2 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("result", core, parent)

	@property
	def absolute(self):
		"""absolute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_absolute'):
			from .Absolute import AbsoluteCls
			self._absolute = AbsoluteCls(self._core, self._cmd_group)
		return self._absolute

	@property
	def relative(self):
		"""relative commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_relative'):
			from .Relative import RelativeCls
			self._relative = RelativeCls(self._core, self._cmd_group)
		return self._relative

	# noinspection PyTypeChecker
	class GetStruct(StructBase):
		"""Response structure. Fields: \n
			- Lower_Gap_Ab: float: No parameter help available
			- Upper_Gap_Ab: float: No parameter help available
			- Lower_Gap_Bc: float: No parameter help available
			- Upper_Gap_Bc: float: No parameter help available
			- Lower_Gap_Cd: float: No parameter help available
			- Upper_Gap_Cd: float: No parameter help available
			- Lower_Gap_De: float: No parameter help available
			- Upper_Gap_De: float: No parameter help available"""
		__meta_args_list = [
			ArgStruct.scalar_float('Lower_Gap_Ab'),
			ArgStruct.scalar_float('Upper_Gap_Ab'),
			ArgStruct.scalar_float('Lower_Gap_Bc'),
			ArgStruct.scalar_float('Upper_Gap_Bc'),
			ArgStruct.scalar_float('Lower_Gap_Cd'),
			ArgStruct.scalar_float('Upper_Gap_Cd'),
			ArgStruct.scalar_float('Lower_Gap_De'),
			ArgStruct.scalar_float('Upper_Gap_De')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Lower_Gap_Ab: float = None
			self.Upper_Gap_Ab: float = None
			self.Lower_Gap_Bc: float = None
			self.Upper_Gap_Bc: float = None
			self.Lower_Gap_Cd: float = None
			self.Upper_Gap_Cd: float = None
			self.Lower_Gap_De: float = None
			self.Upper_Gap_De: float = None

	def get(self, window=repcap.Window.Default, limitIx=repcap.LimitIx.Default, gapChannel=repcap.GapChannel.Default) -> GetStruct:
		"""SCPI: CALCulate<n>:LIMit<li>:ACPower:GAP<gap>[:CACLr]:RESult \n
		Snippet: value: GetStruct = driver.calculate.limit.acPower.gap.caclr.result.get(window = repcap.Window.Default, limitIx = repcap.LimitIx.Default, gapChannel = repcap.GapChannel.Default) \n
		No command help available \n
			:param window: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Calculate')
			:param limitIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Limit')
			:param gapChannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Gap')
			:return: structure: for return value, see the help for GetStruct structure arguments."""
		window_cmd_val = self._cmd_group.get_repcap_cmd_value(window, repcap.Window)
		limitIx_cmd_val = self._cmd_group.get_repcap_cmd_value(limitIx, repcap.LimitIx)
		gapChannel_cmd_val = self._cmd_group.get_repcap_cmd_value(gapChannel, repcap.GapChannel)
		return self._core.io.query_struct(f'CALCulate{window_cmd_val}:LIMit{limitIx_cmd_val}:ACPower:GAP{gapChannel_cmd_val}:CACLr:RESult?', self.__class__.GetStruct())

	def clone(self) -> 'ResultCls':
		"""Clones the group by creating new object from it and its whole existing subgroups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = ResultCls(self._core, self._cmd_group.parent)
		self._cmd_group.synchronize_repcaps(new_group)
		return new_group



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class OffsetCls:
	"""Offset commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("offset", core, parent)

	def set(self, offset: float, externalGen=repcap.ExternalGen.Nr1) -> None:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency:OFFSet \n
		Snippet: driver.source.external.frequency.offset.set(offset = 1.0, externalGen = repcap.ExternalGen.Nr1) \n
		No command help available \n
			:param offset: No help available
			:param externalGen: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.decimal_value_to_str(offset)
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		self._core.io.write(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency:OFFSet {param}')

	def get(self, externalGen=repcap.ExternalGen.Nr1) -> float:
		"""SCPI: SOURce:EXTernal<gen>:FREQuency:OFFSet \n
		Snippet: value: float = driver.source.external.frequency.offset.get(externalGen = repcap.ExternalGen.Nr1) \n
		No command help available \n
			:param externalGen: optional repeated capability selector. Default value: Nr1
			:return: offset: No help available"""
		externalGen_cmd_val = self._cmd_group.get_repcap_cmd_value(externalGen, repcap.ExternalGen)
		response = self._core.io.query_str(f'SOURce:EXTernal{externalGen_cmd_val}:FREQuency:OFFSet?')
		return Conversions.str_to_float(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class AutoCls:
	"""Auto commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("auto", core, parent)

	def set(self, state: bool) -> None:
		"""SCPI: SYSTem:CONFigure:GENerator:INITialise:AUTO \n
		Snippet: driver.applications.k30NoiseFigure.system.configure.generator.initialise.auto.set(state = False) \n
		This command turns automatic connection to the generator on and off. If on, the application automatically configures the
		generator before each measurement and turns on its RF output. Note that you have to establish a connection to the
		generator before you can perform the measurement. The command is available with option R&S FSWP-B10. \n
			:param state: ON | OFF | 1 | 0
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SYSTem:CONFigure:GENerator:INITialise:AUTO {param}')

	def get(self) -> bool:
		"""SCPI: SYSTem:CONFigure:GENerator:INITialise:AUTO \n
		Snippet: value: bool = driver.applications.k30NoiseFigure.system.configure.generator.initialise.auto.get() \n
		This command turns automatic connection to the generator on and off. If on, the application automatically configures the
		generator before each measurement and turns on its RF output. Note that you have to establish a connection to the
		generator before you can perform the measurement. The command is available with option R&S FSWP-B10. \n
			:return: state: ON | OFF | 1 | 0"""
		response = self._core.io.query_str(f'SYSTem:CONFigure:GENerator:INITialise:AUTO?')
		return Conversions.str_to_bool(response)



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import enums
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SourceCls:
	"""Source commands group definition. 1 total commands, 0 Subgroups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("source", core, parent)

	def set(self, source: enums.ReferenceSourceB, externalRosc=repcap.ExternalRosc.Nr1) -> None:
		"""SCPI: SOURce:EXTernal<ext>:ROSCillator[:SOURce] \n
		Snippet: driver.source.external.roscillator.source.set(source = enums.ReferenceSourceB.EAUTo, externalRosc = repcap.ExternalRosc.Nr1) \n
		No command help available \n
			:param source: No help available
			:param externalRosc: optional repeated capability selector. Default value: Nr1
		"""
		param = Conversions.enum_scalar_to_str(source, enums.ReferenceSourceB)
		externalRosc_cmd_val = self._cmd_group.get_repcap_cmd_value(externalRosc, repcap.ExternalRosc)
		self._core.io.write(f'SOURce:EXTernal{externalRosc_cmd_val}:ROSCillator:SOURce {param}')

	# noinspection PyTypeChecker
	def get(self, externalRosc=repcap.ExternalRosc.Nr1) -> enums.ReferenceSourceB:
		"""SCPI: SOURce:EXTernal<ext>:ROSCillator[:SOURce] \n
		Snippet: value: enums.ReferenceSourceB = driver.source.external.roscillator.source.get(externalRosc = repcap.ExternalRosc.Nr1) \n
		No command help available \n
			:param externalRosc: optional repeated capability selector. Default value: Nr1
			:return: source: No help available"""
		externalRosc_cmd_val = self._cmd_group.get_repcap_cmd_value(externalRosc, repcap.ExternalRosc)
		response = self._core.io.query_str(f'SOURce:EXTernal{externalRosc_cmd_val}:ROSCillator:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.ReferenceSourceB)
